import { template, use, isServer } from 'solid-js/web';
import { createMemo, createEffect, onMount, onCleanup, createSignal, splitProps, sharedConfig, untrack } from 'solid-js';
import { useQueryClient, onlineManager } from '@tanstack/solid-query';
import { TanstackQueryDevtools } from '@tanstack/query-devtools';

// src/devtools.tsx
var _tmpl$ = /* @__PURE__ */ template(`<div class=tsqd-parent-container>`);
function SolidQueryDevtools(props) {
  const queryClient = useQueryClient();
  const client = createMemo(() => props.client || queryClient);
  let ref;
  const devtools = new TanstackQueryDevtools({
    client: client(),
    queryFlavor: "Solid Query",
    version: "5",
    onlineManager,
    buttonPosition: props.buttonPosition,
    position: props.position,
    initialIsOpen: props.initialIsOpen,
    errorTypes: props.errorTypes,
    styleNonce: props.styleNonce,
    shadowDOMTarget: props.shadowDOMTarget
  });
  createEffect(() => {
    devtools.setClient(client());
  });
  createEffect(() => {
    const buttonPos = props.buttonPosition;
    if (buttonPos) {
      devtools.setButtonPosition(buttonPos);
    }
  });
  createEffect(() => {
    const pos = props.position;
    if (pos) {
      devtools.setPosition(pos);
    }
  });
  createEffect(() => {
    devtools.setInitialIsOpen(props.initialIsOpen || false);
  });
  createEffect(() => {
    devtools.setErrorTypes(props.errorTypes || []);
  });
  onMount(() => {
    devtools.mount(ref);
    onCleanup(() => devtools.unmount());
  });
  return (() => {
    var _el$ = _tmpl$();
    var _ref$ = ref;
    typeof _ref$ === "function" ? use(_ref$, _el$) : ref = _el$;
    return _el$;
  })();
}
function clientOnly(fn) {
  if (isServer)
    return (props) => props.fallback;
  const [comp, setComp] = createSignal();
  fn().then((m) => setComp(() => m.default));
  return (props) => {
    let Comp;
    let m;
    const [, rest] = splitProps(props, ["fallback"]);
    if ((Comp = comp()) && !sharedConfig.context)
      return Comp(rest);
    const [mounted, setMounted] = createSignal(!sharedConfig.context);
    onMount(() => setMounted(true));
    return createMemo(() => (Comp = comp(), m = mounted(), untrack(() => Comp && m ? Comp(rest) : props.fallback)));
  };
}

export { SolidQueryDevtools, clientOnly };
